==> order-center-domain-3.1.0-CLOUD-DEV-20230626.005721-59-sources.jar: com/tydic/dyc/oc/model/order/qrybo/ConfSupplierQryBo.java <==
package com.tydic.dyc.oc.model.order.qrybo;

import com.tydic.dyc.base.bo.BasePageReqBo;
import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Date;
import java.util.List;


@Data
@EqualsAndHashCode(callSuper=false)
public class ConfSupplierQryBo extends BasePageReqBo {
    /**
     * 供应商ID主键(必填项)
     */
    private Long confId;

    /**
     * 供应商ID主键(必填项)
     */
    private Long supNo;
    /**
     * 供应商名称
     */
    private String supName;
    /**
     * 供应商标识
     */
    private String supType;
    /**
     * 是否一次性发货
     * //            0 否
     * //            1 是
     */
    private Integer isOnceSendAll;
    /**
     * 订单超限额度
     */
    private Long orderQuota;
    /**
     * 订单超限额度 开始
     */
    private Long orderQuotaStart;
    /**
     * 订单超限额度 结束
     */
    private Long orderQuotaEnd;
    /**
     * 校验模式
     */
    private Integer checkFlag;
    /**
     * 接收消息类型
     */
    private String dealType;
    /**
     * 是否完结通知
     * //                        0 否
     * //                        1 是
     */
    private Integer completionFlag;
    /**
     * 业务类型编码
     */
    private String businessTypeCode;
    /**
     * 操作时间
     */
    private Date operatingTime;
    /**
     * 操作时间 开始
     */
    private Date operatingTimeStart;
    /**
     * 操作时间 结束
     */
    private Date operatingTimeEnd;
    /**
     * 操作人ID
     */
    private String operatorId;
    /**
     * 操作人名称
     */
    private String operatorName;
    /**
     * 订单限额额度
     */
    private Long orderLimit;
    /**
     * 订单限额状态：0：生效；1：失效
     */
    private Integer limitStatus;
    /**
     * 排序
     */
    private String orderBy;

    /**
     * 供应商编号列表
     */
    private List<Long> supplierNos;

    @DocField(value = "属性 1系统 2自定义")
    private String sysAttr;

    @DocField(value = "属性翻译")
    private String sysAttrStr;
}

==> order-center-domain-3.2.2-CLOUD-DEV-20240712.005628-31-sources.jar: com/tydic/dyc/oc/model/order/qrybo/ConfSupplierQryBo.java <==
package com.tydic.dyc.oc.model.order.qrybo;

import com.tydic.dyc.base.bo.BasePageReqBo;

import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Date;
import java.util.List;


@Data
@EqualsAndHashCode(callSuper=false)
public class ConfSupplierQryBo extends BasePageReqBo {
    /**
     * 供应商ID主键(必填项)
     */
    private Long confId;

    /**
     * 供应商ID主键(必填项)
     */
    private Long supNo;
    /**
     * 供应商名称
     */
    private String supName;
    /**
     * 供应商标识
     */
    private String supType;
    /**
     * 是否一次性发货
     * //            0 否
     * //            1 是
     */
    private Integer isOnceSendAll;
    /**
     * 订单超限额度
     */
    private Long orderQuota;
    /**
     * 订单超限额度 开始
     */
    private Long orderQuotaStart;
    /**
     * 订单超限额度 结束
     */
    private Long orderQuotaEnd;
    /**
     * 校验模式
     */
    private Integer checkFlag;
    /**
     * 接收消息类型
     */
    private String dealType;
    /**
     * 是否完结通知
     * //                        0 否
     * //                        1 是
     */
    private Integer completionFlag;
    /**
     * 业务类型编码
     */
    private String businessTypeCode;
    /**
     * 操作时间
     */
    private Date operatingTime;
    /**
     * 操作时间 开始
     */
    private Date operatingTimeStart;
    /**
     * 操作时间 结束
     */
    private Date operatingTimeEnd;
    /**
     * 操作人ID
     */
    private String operatorId;
    /**
     * 操作人名称
     */
    private String operatorName;
    /**
     * 订单限额额度
     */
    private Long orderLimit;
    /**
     * 订单限额状态：0：生效；1：失效
     */
    private Integer limitStatus;
    /**
     * 排序
     */
    private String orderBy;

    /**
     * 供应商编号列表
     */
    private List<Long> supplierNos;

    //属性 1系统 2自定义")
    private String sysAttr;

    //属性翻译")
    private String sysAttrStr;
}
